Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(108)

Unified Diff: chrome_frame/test/chrome_frame_unittests.cc

Issue 523040: Some Chrome Frame cleanup:... (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: '' Created 10 years, 12 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome_frame/html_utils_unittest.cc ('k') | chrome_frame/test/html_util_unittests.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome_frame/test/chrome_frame_unittests.cc
===================================================================
--- chrome_frame/test/chrome_frame_unittests.cc (revision 35533)
+++ chrome_frame/test/chrome_frame_unittests.cc (working copy)
@@ -195,7 +195,8 @@
const wchar_t* page, const wchar_t* result_file_to_check) {
std::wstring plugin_path;
PathService::Get(base::DIR_MODULE, &plugin_path);
- file_util::AppendToPath(&plugin_path, L"servers/npchrome_tab.dll");
+ file_util::AppendToPath(&plugin_path, L"servers");
+ file_util::AppendToPath(&plugin_path, kChromeFrameDllName);
static FileVersionInfo* version_info =
FileVersionInfo::CreateFileVersionInfo(plugin_path);
@@ -204,7 +205,7 @@
if (version_info)
version = version_info->product_version();
// If we can't find the npchrome_tab.dll in the src tree, we turn to
// the directory where chrome is installed.
if (!version_info) {
installer::Version* ver_system = InstallUtil::GetChromeVersion(true);
@@ -212,11 +213,11 @@
ASSERT_TRUE(ver_system || ver_user);
bool system_install = ver_system ? true : false;
- std::wstring npchrome_path(installer::GetChromeInstallPath(system_install));
- file_util::AppendToPath(&npchrome_path,
+ std::wstring cf_dll_path(installer::GetChromeInstallPath(system_install));
+ file_util::AppendToPath(&cf_dll_path,
ver_system ? ver_system->GetString() : ver_user->GetString());
- file_util::AppendToPath(&npchrome_path, L"npchrome_tab.dll");
- version_info = FileVersionInfo::CreateFileVersionInfo(npchrome_path);
+ file_util::AppendToPath(&cf_dll_path, kChromeFrameDllName);
+ version_info = FileVersionInfo::CreateFileVersionInfo(cf_dll_path);
if (version_info)
version = version_info->product_version();
}
@@ -204,7 +205,7 @@
if (version_info)
version = version_info->product_version();
- // If we can't find the npchrome_tab.dll in the src tree, we turn to
+ // If we can't find the Chrome Frame DLL in the src tree, we turn to
// the directory where chrome is installed.
if (!version_info) {
« no previous file with comments | « chrome_frame/html_utils_unittest.cc ('k') | chrome_frame/test/html_util_unittests.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698